<?php

    /**

    * This is the PHP Vippy Files API.

    *

    * More tests and Sample code will be available shortly

    *

    * Requires PHP's cURL module.

    *

    * @author yvind Gran <oyvind@citomedia.no>

    * @copyright Copyright (c) 2010, Citomedia AS.

    * 

    * Very basic usage: 

    * 

    * include_once("vippy.class.php");

    * 

    * function request_handle($request)

    * {

    *     //checking for errors

    *     $errorCode = $request->errorCode;

    *     $errorMessage = $request->errorMessage;

    *     if(!empty($errorCode))

    *     {

    *         echo $errorMessage;    

    *     }

    *     else

    *     {

    *         //if no errors, just print the return array

    *         echo("<pre>");

    *         print_r($request);

    *         echo("</pre>");

    *     } 

    * }

    * 

    * $vippy = new Vippy;

    * $opt = array(

    *     'statistics'      => 1

    * );

    * 

    * $request = $vippy->list_videos($opt);

    * request_handle($request);

    * 

    * 

    */



    /**

    * include the settings file, go through it and set up your settings correctly    

    **/

    include_once("config.inc.php");



    Class Vippy{

        

        /**

         * Function to send the actual request, and receive the response. 

         * There is no need to use this function directly, use the other 

         * more convenient functions instead

        */

        function send_request($action="", $opt=Array())

        {

            $opt['client'] = VPY_ACCOUT_ID;

            $opt['token'] = VPY_TOKEN;

            $opt['action'] = $action;

            $opt['format'] = VPY_FORMAT;

            $opt['version'] = VPY_VERSION;

            if($action == "upload_video")

            {

                $opt['file'] = '@'.$opt["video"];    

            }

            

			$ch = curl_init();

            $url = VPY_HOST;

			curl_setopt($ch, CURLOPT_URL, $url);

			curl_setopt($ch, CURLOPT_HEADER, false);

			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

			curl_setopt($ch, CURLOPT_POST, true);

			curl_setopt($ch, CURLOPT_POSTFIELDS, $opt);



			$data = curl_exec($ch);

            $info = curl_getinfo($ch);

            

            curl_close($ch);



            if(VPY_FORMAT == "json")

            {

                try

                {

                    $r = $data;

                    /*$r = json_decode($data);

                    if ($r === null) {

                        throw new Exception("Failed to decode $data as json");

                    } */   

                }

                catch (Exception $e) 

                {

                    var_dump($e->getMessage());

                } 

            }

            elseif(VPY_FORMAT == "xml")

            {

                try

                {

                    $r = simplexml_load_string($data, null, LIBXML_NOCDATA); //LIBXML_NOCDATA

                    /*if ($r === null) {

                        throw new Exception("Failed to decode $data as xml");

                    } */  

                }

                catch (Exception $e) 

                {

                    var_dump($e->getMessage());

                }     

            }

            else

            {

                $r = "Wrong format";    

            }   

            return $r;

        }

        

        /**

         * Authenticate

         * 

         * 

         * 

         * 

        */

        

        function authenticate($opt=Array()){

            $pw = md5($opt["password"]);

            $opt["password"] = $pw;

            return $this->send_request('authenticate', $opt);

        }





        /**

         * Upload a video file

         * 

         * Function to upload a new video, can take up 

         * to 8 parameters, which of 3 are mandatory. 

         * 

         * The different parameters are:

         *  

         * video: mandatory, url to the video you want to upload.

         * contentType: mandatory, the content-type of your video

         * title: mandatory, the title of your video

         * description: optional, description of your video

         * tags: optional, tags for your video, commaseparated

         * quality: the quality you want your video to be encoded to, 

         *          can be either higher, normal or lower

         * notify: url to script which we will notify when the encoding process is done, optional

         * uploadedby: name of the person who uploaded the video, optional

         * 

         * Typical usage: 

         * 

         * include_once("vippy.class.php");

         * $vippy = new Vippy;

         * $opt = array(

         *      'video'        => 'fourseasons.mp4',

         *      'contentType'  => 'video/mp4',

         *      'title'        => 'Four seasons',

         *      'description'  => 'Just another videofile', 

         *      'tags'         => 'summer, winter, autumn, spring', 

         *      'quality'      => 'normal', 

         *      'uploadedby'   => 'yourname', 

         *      'notify'       => 'http://yourdomain.com/notify.php'

         * );

         * 

         * $request = $vippy -> upload_video($opt);

         * 

         * Returns an array with either errormessage, or successmessages

         * 

        */

        function upload_video($opt=Array()){

            return $this->send_request('upload_video', $opt);

        }

        

        /**

         * List all your video files

         * 

         * Function to get all your videos, takes only one parameter 

         * 

         * The different parameters are:

         *  

         * statistics: optional, set this to 1 if you want some 

         *             simple video statistics included with the response

         * 

         * Typical usage: 

         * 

         * include_once("vippy.class.php");

         * $vippy = new Vippy;

         * $opt = array(

         *      'statistics' => 1

         * );

         * 

         * $request = $vippy -> list_videos($opt);

         * 

         * Returns an array with all your videos and different 

         * useful values for each video inlcuding the videoId's'

         * 

        */

        public function list_videos($opt=Array())

        {

            return $this->send_request('list_videos', $opt);

        }

        

        /**

         * List all your video players

         * 

         * Function to get all your videoplayers, takes no parameters 

         * 

         * Typical usage: 

         * 

         * include_once("vippy.class.php");

         * $vippy = new Vippy;

         * 

         * $request = $vippy -> list_players($opt);

         * 

         * Returns an array with all your videoplayers and 

         * different useful values for each videoplayer 

         * 

        */

        function list_players($opt=Array())

        {

            return $this->send_request('list_players', $opt);

        }

        

        /**

         *             

         * Get the embedcode of a video

         * 

         * Function to get the embedcode to a certain video, remember 

         * that you will also need to put in some code in the HEAD 

         * section of your HTML document to get this to work properly, 

         * can take up to 7 parameters which of 1 is mandatory 

         * 

         * The different parameters are:

         *  

         * videoId: mandatory, the videoId of the specific video

         * playerId: optional, if no playerId is specified, your default 

         *           player will be used

         * size: optional, if no size is specified, the dimensions of your 

         *       embedded video will be taken from the player(default player 

         *       if no player is specified)

         * embedcode: optional, to specify  if you want to enable the function for sharing the embedcode

         * facebook: optional, to specify if you want to enable the share on facebook function

         * twitter: optional, to specify if you want to enable the share on twitter function

         * logo: optional, to specify a logo you want to use on your embedded player, takes a logoId as value

         * 

         * Typical usage: 

         * 

         * include_once("vippy.class.php");

         * $vippy = new Vippy;

         * $opt = array(

         *      'videoId'      => 1205,

         *      'playerId'     => 45,

         *      'size'         => "690x480",

         *   	'embedcode'    => 0,

         *   	'facebook'     => 1, 

         *      'twitter'      => 1, 

         *      'logo'         => 256

         * );

         *

         * $request = $vippy->get_embedcode($opt);

         * 

         * Returns an array with 3 different html codes, head section, html embedcode and flash embedcode

         * 

        */

        function get_embedcode($opt=Array())

        {

            return $this->send_request('get_embedcode', $opt);

        }

        

        /**

         *             

         * Delete a video file

         * 

         * Function to delete an existing video file, takes 1 parameter 

         * 

         * The different parameters are:

         *  

         * videoId: mandatory, the videoId of the video you want to delete

         * 

         * Typical usage: 

         * 

         * include_once("vippy.class.php");

         * $vippy = new Vippy;

         * $opt = array(

         *      'videoId'      => 1205

         * );

         *

         * $request = $vippy->delete_video($opt);

         *                                                        

         * Returns either error or success messages

         * 

        */

        function delete_video($opt=Array())

        {

            return $this->send_request('delete_video', $opt);

        }

        

        /**

         *             

         * Update an existing video file

         * 

         * Function to get update a video file and set new title, description and tags 

         * 

         * The different parameters are:

         *  

         * videoId: mandatory, the videoId of the video you want to update

         * title: optional, the title of your video

         * description: optional, description of your video

         * tags: optional, tags for your video, commaseparated

         * 

         * Typical usage: 

         * 

         * include_once("vippy.class.php");

         * $vippy = new Vippy;

         * $opt = array(

         *      'videoId'      => 1205,

         *      'title'        => 'This i a new title',

         *      'description'  => 'This is a new description',

         *   	'tags'         => 'new tag 1, new tag 2'

         * );

         *

         * $request = $vippy->update_video($opt);

         * 

         * Returns either error or success messages

         * 

        */

        function update_video($opt=Array())

        {

            return $this->send_request('update_video', $opt);

        }

        

        /**

         * Get a spesific video

         * 

         * Function to get one spesific video, takes 2 parameters

         * 

         * The different parameters are:

         *  

         * videoId: mandatory, the videoId of the video you want to update

         * statistics: optional, set this to 1 if you want some simple video 

         *             statistics included with the response

         * 

         * Typical usage: 

         * 

         * include_once("vippy.class.php");

         * $vippy = new Vippy;

         * 

         * $opt = array(

         *      'videoId'      => 1205,

         *      'statistics'   => 1

         * );

         * 

         * $request = $vippy -> get_video($opt);

         * 

         * Returns an array with useful information about your video 

         * 

        */

        function get_video($opt=Array())

        {

            return $this->send_request('get_video', $opt);

        }

        

        /**

         * Get logo(s)

         * 

         * Function to get a list of your uploaded logos, or just one spesific logo, takes 1 optional parameter

         * 

         * The different parameters are:

         *  

         * logoId: optional, specify this to only retrieve infomation about a spesific logo

         * 

         * Typical usage: 

         * 

         * include_once("vippy.class.php");

         * $vippy = new Vippy;

         * 

         * $opt = array(

         *      'logoId'      => 542

         * );

         * 

         * $request = $vippy -> get_logos($opt);

         * 

         * Returns an array with useful information about your logo(s) 

         * 

        */

        function get_logos($opt=Array())

        {

            return $this->send_request('get_logos', $opt);

        }

        

        /**

         * Get usage statistics

         * 

         * Function to get some simple statistics about the current usage, takes 2 parameters

         * 

         * The different parameters are:

         *  

         * month: mandatory, the current month you want usage statistics for

         * year: mandatory, the current year you want usage statistics for

         * 

         * Typical usage: 

         * 

         * include_once("vippy.class.php");

         * $vippy = new Vippy;

         * 

         * $opt = array(

         *      'month'      => 10, 

         *      'year'       => 2010

         * );

         * 

         * $request = $vippy -> get_usage($opt);

         * 

         * Return the current usage in the spesified month in bytes, also returns available monthly streaming in bytes 

         * 

        */

        function get_usage($opt=Array())

        {

            return $this->send_request('get_usage', $opt);

        }

        

        /**

         * get an array of thumbs for videos

         * 

         * Function to get thumbnails for videos, returns an array with videoId and thumbnail location, takes one parameter

         * 

         * The different parameters are:

         *  

         * an array of videoId's

         * 

         * Typical usage: 

         * 

         * include_once("vippy.class.php");

         * $vippy = new Vippy;

         * 

         * $opt = array(34, 343, 87, 45, etc);

         * 

         * $opt = array(

         *      'videoId'    => Array(34, 343, 87, 45, etc)

         * );

         * 

         * $request = $vippy -> get_video_thumbs($opt);

         * 

         * Returns an array of thumbsnails and videoId's

         * 

        */

        function get_video_thumbs($opt=Array())

        {

            if(is_array($opt["videoId"]))

            {

                $videos = base64_encode(serialize($opt["videoId"]));

            }

            $opt["videos"] = $videos;

            return $this->send_request('get_video_thumbs', $opt);

        }        

        

    }

    

?>